@@ -1,7 +1,7 @@
 package Module::DataPack;
 
-our $DATE = '2015-08-01'; # DATE
-our $VERSION = '0.09'; # VERSION
+our $DATE = '2015-09-03'; # DATE
+our $VERSION = '0.10'; # VERSION
 
 use 5.010001;
 use strict;
@@ -244,7 +244,7 @@ Module::DataPack - Like Module::FatPack, but uses datapacking instead of fatpack
 
 =head1 VERSION
 
-This document describes version 0.09 of Module::DataPack (from Perl distribution Module-DataPack), released on 2015-08-01.
+This document describes version 0.10 of Module::DataPack (from Perl distribution Module-DataPack), released on 2015-09-03.
 
 =head1 SEE ALSO
 
@@ -259,9 +259,8 @@ L<datapack-modules>, CLI for C<datapack_modules>.
 
 =head2 datapack_modules(%args) -> [status, msg, result, meta]
 
-{en_US Like Module::FatPack, but uses datapacking instead of fatpack}.
+Like Module::FatPack, but uses datapacking instead of fatpack.
 
-{en_US 
 Both this module and C<Module:FatPack> generate source code that embeds modules'
 source codes and load them on-demand via require hook. The difference is that
 the modules' source codes are put in C<__DATA__> section instead of regular Perl
@@ -277,7 +276,6 @@ section is not yet available. You can only use run-time require()'s.
 
 Another downside of this technique is that you cannot use C<__DATA__> section for
 other purposes (well, actually with some care, you still can).
-}
 
 Arguments ('*' denotes required arguments):
 
@@ -285,51 +283,51 @@ Arguments ('*' denotes required arguments):
 
 =item * B<module_names> => I<array[str]>
 
-{en_US Module names to search}.
+Module names to search.
 
 =item * B<module_srcs> => I<hash>
 
-{en_US Module source codes (a hash, keys are module names)}.
+Module source codes (a hash, keys are module names).
 
 =item * B<output> => I<str>
 
-{en_US Output filename}.
+Output filename.
 
 =item * B<overwrite> => I<bool> (default: 0)
 
-{en_US Whether to overwrite output if previously exists}.
+Whether to overwrite output if previously exists.
 
 =item * B<postamble> => I<str>
 
-{en_US Perl source code to add after the datapack code (but before the __DATA__ section)}.
+Perl source code to add after the datapack code (but before the __DATA__ section).
 
 =item * B<preamble> => I<str>
 
-{en_US Perl source code to add before the datapack code}.
+Perl source code to add before the datapack code.
 
 =item * B<stripper> => I<bool> (default: 0)
 
-{en_US Whether to strip included modules using Perl::Stripper}.
+Whether to strip included modules using Perl::Stripper.
 
 =item * B<stripper_comment> => I<bool> (default: 1)
 
-{en_US Set strip_comment=1 (strip comments) in Perl::Stripper}.
+Set strip_comment=1 (strip comments) in Perl::Stripper.
 
 =item * B<stripper_log> => I<bool> (default: 0)
 
-{en_US Set strip_log=1 (strip log statements) in Perl::Stripper}.
+Set strip_log=1 (strip log statements) in Perl::Stripper.
 
 =item * B<stripper_maintain_linum> => I<bool> (default: 0)
 
-{en_US Set maintain_linum=1 in Perl::Stripper}.
+Set maintain_linum=1 in Perl::Stripper.
 
 =item * B<stripper_pod> => I<bool> (default: 1)
 
-{en_US Set strip_pod=1 (strip POD) in Perl::Stripper}.
+Set strip_pod=1 (strip POD) in Perl::Stripper.
 
 =item * B<stripper_ws> => I<bool> (default: 1)
 
-{en_US Set strip_ws=1 (strip whitespace) in Perl::Stripper}.
+Set strip_ws=1 (strip whitespace) in Perl::Stripper.
 
 =back
 
